# GWXtreme
Tools for inferences on extreme matter using gravitational wave parameter estimation data. For details on using this package please refer to the [documentation](https://gwxtreme.readthedocs.io/en/latest/).

Currently available tools:
--------------------------
1.  Model selection of neutron star equation of state using gravitational wave parameter estimation results.
